"""
Type annotations for glacier service client waiters.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_glacier/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_glacier.client import GlacierClient
    from types_boto3_glacier.waiter import (
        VaultExistsWaiter,
        VaultNotExistsWaiter,
    )

    session = Session()
    client: GlacierClient = session.client("glacier")

    vault_exists_waiter: VaultExistsWaiter = client.get_waiter("vault_exists")
    vault_not_exists_waiter: VaultNotExistsWaiter = client.get_waiter("vault_not_exists")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys

from botocore.waiter import Waiter

from .type_defs import (
    DescribeVaultInputVaultExistsWaitTypeDef,
    DescribeVaultInputVaultNotExistsWaitTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = ("VaultExistsWaiter", "VaultNotExistsWaiter")

class VaultExistsWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/glacier/waiter/VaultExists.html#Glacier.Waiter.VaultExists)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_glacier/waiters/#vaultexistswaiter)
    """
    def wait(self, **kwargs: Unpack[DescribeVaultInputVaultExistsWaitTypeDef]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/glacier/waiter/VaultExists.html#Glacier.Waiter.VaultExists.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_glacier/waiters/#vaultexistswaiter)
        """

class VaultNotExistsWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/glacier/waiter/VaultNotExists.html#Glacier.Waiter.VaultNotExists)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_glacier/waiters/#vaultnotexistswaiter)
    """
    def wait(self, **kwargs: Unpack[DescribeVaultInputVaultNotExistsWaitTypeDef]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/glacier/waiter/VaultNotExists.html#Glacier.Waiter.VaultNotExists.wait)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_glacier/waiters/#vaultnotexistswaiter)
        """
