"""
Type annotations for iotsitewise service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_iotsitewise.client import IoTSiteWiseClient
    from types_boto3_iotsitewise.paginator import (
        ExecuteQueryPaginator,
        GetAssetPropertyAggregatesPaginator,
        GetAssetPropertyValueHistoryPaginator,
        GetInterpolatedAssetPropertyValuesPaginator,
        ListAccessPoliciesPaginator,
        ListActionsPaginator,
        ListAssetModelCompositeModelsPaginator,
        ListAssetModelPropertiesPaginator,
        ListAssetModelsPaginator,
        ListAssetPropertiesPaginator,
        ListAssetRelationshipsPaginator,
        ListAssetsPaginator,
        ListAssociatedAssetsPaginator,
        ListBulkImportJobsPaginator,
        ListCompositionRelationshipsPaginator,
        ListDashboardsPaginator,
        ListDatasetsPaginator,
        ListGatewaysPaginator,
        ListPortalsPaginator,
        ListProjectAssetsPaginator,
        ListProjectsPaginator,
        ListTimeSeriesPaginator,
    )

    session = Session()
    client: IoTSiteWiseClient = session.client("iotsitewise")

    execute_query_paginator: ExecuteQueryPaginator = client.get_paginator("execute_query")
    get_asset_property_aggregates_paginator: GetAssetPropertyAggregatesPaginator = client.get_paginator("get_asset_property_aggregates")
    get_asset_property_value_history_paginator: GetAssetPropertyValueHistoryPaginator = client.get_paginator("get_asset_property_value_history")
    get_interpolated_asset_property_values_paginator: GetInterpolatedAssetPropertyValuesPaginator = client.get_paginator("get_interpolated_asset_property_values")
    list_access_policies_paginator: ListAccessPoliciesPaginator = client.get_paginator("list_access_policies")
    list_actions_paginator: ListActionsPaginator = client.get_paginator("list_actions")
    list_asset_model_composite_models_paginator: ListAssetModelCompositeModelsPaginator = client.get_paginator("list_asset_model_composite_models")
    list_asset_model_properties_paginator: ListAssetModelPropertiesPaginator = client.get_paginator("list_asset_model_properties")
    list_asset_models_paginator: ListAssetModelsPaginator = client.get_paginator("list_asset_models")
    list_asset_properties_paginator: ListAssetPropertiesPaginator = client.get_paginator("list_asset_properties")
    list_asset_relationships_paginator: ListAssetRelationshipsPaginator = client.get_paginator("list_asset_relationships")
    list_assets_paginator: ListAssetsPaginator = client.get_paginator("list_assets")
    list_associated_assets_paginator: ListAssociatedAssetsPaginator = client.get_paginator("list_associated_assets")
    list_bulk_import_jobs_paginator: ListBulkImportJobsPaginator = client.get_paginator("list_bulk_import_jobs")
    list_composition_relationships_paginator: ListCompositionRelationshipsPaginator = client.get_paginator("list_composition_relationships")
    list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
    list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
    list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
    list_portals_paginator: ListPortalsPaginator = client.get_paginator("list_portals")
    list_project_assets_paginator: ListProjectAssetsPaginator = client.get_paginator("list_project_assets")
    list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
    list_time_series_paginator: ListTimeSeriesPaginator = client.get_paginator("list_time_series")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ExecuteQueryRequestExecuteQueryPaginateTypeDef,
    ExecuteQueryResponsePaginatorTypeDef,
    GetAssetPropertyAggregatesRequestGetAssetPropertyAggregatesPaginateTypeDef,
    GetAssetPropertyAggregatesResponseTypeDef,
    GetAssetPropertyValueHistoryRequestGetAssetPropertyValueHistoryPaginateTypeDef,
    GetAssetPropertyValueHistoryResponseTypeDef,
    GetInterpolatedAssetPropertyValuesRequestGetInterpolatedAssetPropertyValuesPaginateTypeDef,
    GetInterpolatedAssetPropertyValuesResponseTypeDef,
    ListAccessPoliciesRequestListAccessPoliciesPaginateTypeDef,
    ListAccessPoliciesResponseTypeDef,
    ListActionsRequestListActionsPaginateTypeDef,
    ListActionsResponseTypeDef,
    ListAssetModelCompositeModelsRequestListAssetModelCompositeModelsPaginateTypeDef,
    ListAssetModelCompositeModelsResponseTypeDef,
    ListAssetModelPropertiesRequestListAssetModelPropertiesPaginateTypeDef,
    ListAssetModelPropertiesResponseTypeDef,
    ListAssetModelsRequestListAssetModelsPaginateTypeDef,
    ListAssetModelsResponseTypeDef,
    ListAssetPropertiesRequestListAssetPropertiesPaginateTypeDef,
    ListAssetPropertiesResponseTypeDef,
    ListAssetRelationshipsRequestListAssetRelationshipsPaginateTypeDef,
    ListAssetRelationshipsResponseTypeDef,
    ListAssetsRequestListAssetsPaginateTypeDef,
    ListAssetsResponseTypeDef,
    ListAssociatedAssetsRequestListAssociatedAssetsPaginateTypeDef,
    ListAssociatedAssetsResponseTypeDef,
    ListBulkImportJobsRequestListBulkImportJobsPaginateTypeDef,
    ListBulkImportJobsResponseTypeDef,
    ListCompositionRelationshipsRequestListCompositionRelationshipsPaginateTypeDef,
    ListCompositionRelationshipsResponseTypeDef,
    ListDashboardsRequestListDashboardsPaginateTypeDef,
    ListDashboardsResponseTypeDef,
    ListDatasetsRequestListDatasetsPaginateTypeDef,
    ListDatasetsResponseTypeDef,
    ListGatewaysRequestListGatewaysPaginateTypeDef,
    ListGatewaysResponseTypeDef,
    ListPortalsRequestListPortalsPaginateTypeDef,
    ListPortalsResponseTypeDef,
    ListProjectAssetsRequestListProjectAssetsPaginateTypeDef,
    ListProjectAssetsResponseTypeDef,
    ListProjectsRequestListProjectsPaginateTypeDef,
    ListProjectsResponseTypeDef,
    ListTimeSeriesRequestListTimeSeriesPaginateTypeDef,
    ListTimeSeriesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ExecuteQueryPaginator",
    "GetAssetPropertyAggregatesPaginator",
    "GetAssetPropertyValueHistoryPaginator",
    "GetInterpolatedAssetPropertyValuesPaginator",
    "ListAccessPoliciesPaginator",
    "ListActionsPaginator",
    "ListAssetModelCompositeModelsPaginator",
    "ListAssetModelPropertiesPaginator",
    "ListAssetModelsPaginator",
    "ListAssetPropertiesPaginator",
    "ListAssetRelationshipsPaginator",
    "ListAssetsPaginator",
    "ListAssociatedAssetsPaginator",
    "ListBulkImportJobsPaginator",
    "ListCompositionRelationshipsPaginator",
    "ListDashboardsPaginator",
    "ListDatasetsPaginator",
    "ListGatewaysPaginator",
    "ListPortalsPaginator",
    "ListProjectAssetsPaginator",
    "ListProjectsPaginator",
    "ListTimeSeriesPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ExecuteQueryPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ExecuteQuery.html#IoTSiteWise.Paginator.ExecuteQuery)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#executequerypaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ExecuteQueryRequestExecuteQueryPaginateTypeDef]
    ) -> _PageIterator[ExecuteQueryResponsePaginatorTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ExecuteQuery.html#IoTSiteWise.Paginator.ExecuteQuery.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#executequerypaginator)
        """


class GetAssetPropertyAggregatesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/GetAssetPropertyAggregates.html#IoTSiteWise.Paginator.GetAssetPropertyAggregates)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#getassetpropertyaggregatespaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            GetAssetPropertyAggregatesRequestGetAssetPropertyAggregatesPaginateTypeDef
        ],
    ) -> _PageIterator[GetAssetPropertyAggregatesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/GetAssetPropertyAggregates.html#IoTSiteWise.Paginator.GetAssetPropertyAggregates.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#getassetpropertyaggregatespaginator)
        """


class GetAssetPropertyValueHistoryPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/GetAssetPropertyValueHistory.html#IoTSiteWise.Paginator.GetAssetPropertyValueHistory)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#getassetpropertyvaluehistorypaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            GetAssetPropertyValueHistoryRequestGetAssetPropertyValueHistoryPaginateTypeDef
        ],
    ) -> _PageIterator[GetAssetPropertyValueHistoryResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/GetAssetPropertyValueHistory.html#IoTSiteWise.Paginator.GetAssetPropertyValueHistory.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#getassetpropertyvaluehistorypaginator)
        """


class GetInterpolatedAssetPropertyValuesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/GetInterpolatedAssetPropertyValues.html#IoTSiteWise.Paginator.GetInterpolatedAssetPropertyValues)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#getinterpolatedassetpropertyvaluespaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            GetInterpolatedAssetPropertyValuesRequestGetInterpolatedAssetPropertyValuesPaginateTypeDef
        ],
    ) -> _PageIterator[GetInterpolatedAssetPropertyValuesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/GetInterpolatedAssetPropertyValues.html#IoTSiteWise.Paginator.GetInterpolatedAssetPropertyValues.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#getinterpolatedassetpropertyvaluespaginator)
        """


class ListAccessPoliciesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAccessPolicies.html#IoTSiteWise.Paginator.ListAccessPolicies)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listaccesspoliciespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListAccessPoliciesRequestListAccessPoliciesPaginateTypeDef]
    ) -> _PageIterator[ListAccessPoliciesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAccessPolicies.html#IoTSiteWise.Paginator.ListAccessPolicies.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listaccesspoliciespaginator)
        """


class ListActionsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListActions.html#IoTSiteWise.Paginator.ListActions)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listactionspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListActionsRequestListActionsPaginateTypeDef]
    ) -> _PageIterator[ListActionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListActions.html#IoTSiteWise.Paginator.ListActions.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listactionspaginator)
        """


class ListAssetModelCompositeModelsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetModelCompositeModels.html#IoTSiteWise.Paginator.ListAssetModelCompositeModels)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetmodelcompositemodelspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListAssetModelCompositeModelsRequestListAssetModelCompositeModelsPaginateTypeDef
        ],
    ) -> _PageIterator[ListAssetModelCompositeModelsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetModelCompositeModels.html#IoTSiteWise.Paginator.ListAssetModelCompositeModels.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetmodelcompositemodelspaginator)
        """


class ListAssetModelPropertiesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetModelProperties.html#IoTSiteWise.Paginator.ListAssetModelProperties)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetmodelpropertiespaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[ListAssetModelPropertiesRequestListAssetModelPropertiesPaginateTypeDef],
    ) -> _PageIterator[ListAssetModelPropertiesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetModelProperties.html#IoTSiteWise.Paginator.ListAssetModelProperties.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetmodelpropertiespaginator)
        """


class ListAssetModelsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetModels.html#IoTSiteWise.Paginator.ListAssetModels)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetmodelspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListAssetModelsRequestListAssetModelsPaginateTypeDef]
    ) -> _PageIterator[ListAssetModelsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetModels.html#IoTSiteWise.Paginator.ListAssetModels.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetmodelspaginator)
        """


class ListAssetPropertiesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetProperties.html#IoTSiteWise.Paginator.ListAssetProperties)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetpropertiespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListAssetPropertiesRequestListAssetPropertiesPaginateTypeDef]
    ) -> _PageIterator[ListAssetPropertiesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetProperties.html#IoTSiteWise.Paginator.ListAssetProperties.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetpropertiespaginator)
        """


class ListAssetRelationshipsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetRelationships.html#IoTSiteWise.Paginator.ListAssetRelationships)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetrelationshipspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListAssetRelationshipsRequestListAssetRelationshipsPaginateTypeDef]
    ) -> _PageIterator[ListAssetRelationshipsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssetRelationships.html#IoTSiteWise.Paginator.ListAssetRelationships.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetrelationshipspaginator)
        """


class ListAssetsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssets.html#IoTSiteWise.Paginator.ListAssets)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListAssetsRequestListAssetsPaginateTypeDef]
    ) -> _PageIterator[ListAssetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssets.html#IoTSiteWise.Paginator.ListAssets.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassetspaginator)
        """


class ListAssociatedAssetsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssociatedAssets.html#IoTSiteWise.Paginator.ListAssociatedAssets)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassociatedassetspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListAssociatedAssetsRequestListAssociatedAssetsPaginateTypeDef]
    ) -> _PageIterator[ListAssociatedAssetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListAssociatedAssets.html#IoTSiteWise.Paginator.ListAssociatedAssets.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listassociatedassetspaginator)
        """


class ListBulkImportJobsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListBulkImportJobs.html#IoTSiteWise.Paginator.ListBulkImportJobs)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listbulkimportjobspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListBulkImportJobsRequestListBulkImportJobsPaginateTypeDef]
    ) -> _PageIterator[ListBulkImportJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListBulkImportJobs.html#IoTSiteWise.Paginator.ListBulkImportJobs.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listbulkimportjobspaginator)
        """


class ListCompositionRelationshipsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListCompositionRelationships.html#IoTSiteWise.Paginator.ListCompositionRelationships)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listcompositionrelationshipspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[
            ListCompositionRelationshipsRequestListCompositionRelationshipsPaginateTypeDef
        ],
    ) -> _PageIterator[ListCompositionRelationshipsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListCompositionRelationships.html#IoTSiteWise.Paginator.ListCompositionRelationships.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listcompositionrelationshipspaginator)
        """


class ListDashboardsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListDashboards.html#IoTSiteWise.Paginator.ListDashboards)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listdashboardspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDashboardsRequestListDashboardsPaginateTypeDef]
    ) -> _PageIterator[ListDashboardsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListDashboards.html#IoTSiteWise.Paginator.ListDashboards.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listdashboardspaginator)
        """


class ListDatasetsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListDatasets.html#IoTSiteWise.Paginator.ListDatasets)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listdatasetspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDatasetsRequestListDatasetsPaginateTypeDef]
    ) -> _PageIterator[ListDatasetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListDatasets.html#IoTSiteWise.Paginator.ListDatasets.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listdatasetspaginator)
        """


class ListGatewaysPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListGateways.html#IoTSiteWise.Paginator.ListGateways)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listgatewayspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListGatewaysRequestListGatewaysPaginateTypeDef]
    ) -> _PageIterator[ListGatewaysResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListGateways.html#IoTSiteWise.Paginator.ListGateways.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listgatewayspaginator)
        """


class ListPortalsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListPortals.html#IoTSiteWise.Paginator.ListPortals)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listportalspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListPortalsRequestListPortalsPaginateTypeDef]
    ) -> _PageIterator[ListPortalsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListPortals.html#IoTSiteWise.Paginator.ListPortals.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listportalspaginator)
        """


class ListProjectAssetsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListProjectAssets.html#IoTSiteWise.Paginator.ListProjectAssets)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listprojectassetspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListProjectAssetsRequestListProjectAssetsPaginateTypeDef]
    ) -> _PageIterator[ListProjectAssetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListProjectAssets.html#IoTSiteWise.Paginator.ListProjectAssets.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listprojectassetspaginator)
        """


class ListProjectsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListProjects.html#IoTSiteWise.Paginator.ListProjects)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listprojectspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListProjectsRequestListProjectsPaginateTypeDef]
    ) -> _PageIterator[ListProjectsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListProjects.html#IoTSiteWise.Paginator.ListProjects.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listprojectspaginator)
        """


class ListTimeSeriesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListTimeSeries.html#IoTSiteWise.Paginator.ListTimeSeries)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listtimeseriespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTimeSeriesRequestListTimeSeriesPaginateTypeDef]
    ) -> _PageIterator[ListTimeSeriesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iotsitewise/paginator/ListTimeSeries.html#IoTSiteWise.Paginator.ListTimeSeries.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_iotsitewise/paginators/#listtimeseriespaginator)
        """
