"""
Type annotations for mediastore-data service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_mediastore_data.client import MediaStoreDataClient
    from types_boto3_mediastore_data.paginator import (
        ListItemsPaginator,
    )

    session = Session()
    client: MediaStoreDataClient = session.client("mediastore-data")

    list_items_paginator: ListItemsPaginator = client.get_paginator("list_items")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListItemsRequestListItemsPaginateTypeDef, ListItemsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = ("ListItemsPaginator",)

_ItemTypeDef = TypeVar("_ItemTypeDef")

class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """

class ListItemsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore-data/paginator/ListItems.html#MediaStoreData.Paginator.ListItems)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/#listitemspaginator)
    """
    def paginate(
        self, **kwargs: Unpack[ListItemsRequestListItemsPaginateTypeDef]
    ) -> _PageIterator[ListItemsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediastore-data/paginator/ListItems.html#MediaStoreData.Paginator.ListItems.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_mediastore_data/paginators/#listitemspaginator)
        """
