"""
Type annotations for timestream-influxdb service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_timestream_influxdb/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_timestream_influxdb.client import TimestreamInfluxDBClient
    from types_boto3_timestream_influxdb.paginator import (
        ListDbInstancesPaginator,
        ListDbParameterGroupsPaginator,
    )

    session = Session()
    client: TimestreamInfluxDBClient = session.client("timestream-influxdb")

    list_db_instances_paginator: ListDbInstancesPaginator = client.get_paginator("list_db_instances")
    list_db_parameter_groups_paginator: ListDbParameterGroupsPaginator = client.get_paginator("list_db_parameter_groups")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListDbInstancesInputListDbInstancesPaginateTypeDef,
    ListDbInstancesOutputTypeDef,
    ListDbParameterGroupsInputListDbParameterGroupsPaginateTypeDef,
    ListDbParameterGroupsOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListDbInstancesPaginator", "ListDbParameterGroupsPaginator")


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListDbInstancesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/timestream-influxdb/paginator/ListDbInstances.html#TimestreamInfluxDB.Paginator.ListDbInstances)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_timestream_influxdb/paginators/#listdbinstancespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDbInstancesInputListDbInstancesPaginateTypeDef]
    ) -> _PageIterator[ListDbInstancesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/timestream-influxdb/paginator/ListDbInstances.html#TimestreamInfluxDB.Paginator.ListDbInstances.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_timestream_influxdb/paginators/#listdbinstancespaginator)
        """


class ListDbParameterGroupsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/timestream-influxdb/paginator/ListDbParameterGroups.html#TimestreamInfluxDB.Paginator.ListDbParameterGroups)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_timestream_influxdb/paginators/#listdbparametergroupspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListDbParameterGroupsInputListDbParameterGroupsPaginateTypeDef]
    ) -> _PageIterator[ListDbParameterGroupsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/timestream-influxdb/paginator/ListDbParameterGroups.html#TimestreamInfluxDB.Paginator.ListDbParameterGroups.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_timestream_influxdb/paginators/#listdbparametergroupspaginator)
        """
